Learn R Programming

eco (version 3.1-2)

forgnlit30c: Foreign-born literacy in 1930, County Level

Description

This data set contains, on a county level, the proportion of white residents ten years and older who are foreign born, and the proportion of those residents who are literate. Data come from the 1930 census and were first analyzed by Robinson (1950). Counties with fewer than 100 foreign born residents are dropped.

Usage

data(forgnlit30c)

Arguments

format

A data frame containing 6 variables and 1976 observations lll{ X numeric proportion of the white population at least 10 years of age that is foreign born Y numeric proportion of the white population at least 10 years of age that is illiterate W1 numeric proportion of the foreign-born white population at least 10 years of age that is illiterate W2 numeric proportion of the native-born white population at least 10 years of age that is illiterate state numeric the ICPSR state code county numeric the ICPSR (within state) county code }

References

Robinson, W.S. (1950). ``Ecological Correlations and the Behavior of Individuals.'' American Sociological Review, vol. 15, pp.351-357.