Learn R Programming

eco (version 1.1-1)

summary.eco: Summarizing the results for the nonparametric and parametric models for ecological inference in 2 by 2 tables

Description

summary method for class eco.

Usage

## S3 method for class 'eco':
summary(object, CI=c(2.5, 97.5), long = FALSE, ...)

## S3 method for class 'summary.eco': print(x, digits = max(3, getOption("digits") - 3), ...)

Arguments

object
An output object from eco.
CI
A 2 dimensional vector of lower and upper bounds for the credible intervals used to summarize the results. The default is the equal tail 95 percent credible interval.
x
An object of class summary.eco.
digits
the number of significant digits to use when printing.
long
Logical. If TRUE, the in-sample predictions for each unit will be provided. The default value is FALSE.
...
further arguments passed to or from other methods.

Value

  • summary.eco yields an object of class summary.eco containing the following elements:
  • callThe call from eco.
  • nonparThe logical variable indicating whether the results are based on the parametric or nonparametric model.
  • n.obsThe number of units.
  • agg.tableAggregate posterior estimates of the marginal means of $W_1$ and $W_2$.
  • If long = TRUE, the following elements are also included:
  • W1.tableUnit-level posterior estimates for $W_1$.
  • W2.tableUnit-level posterior estimates for $W_2$.
  • This object can be printed by print.summary.eco

See Also

eco