Learn R Programming

eco (version 3.1-7)

summary.eco: Summarizing the Results for the Bayesian Parametric Model for Ecological Inference in 2x2 Tables

Description

summary method for class eco.

Usage

# S3 method for eco
summary(object, CI = c(2.5, 97.5), param = TRUE,
          units = FALSE, subset = NULL, ...) 

# S3 method for summary.eco print(x, digits = max(3, getOption("digits") - 3), ...)

Arguments

object

An output object from eco.

CI

A vector of lower and upper bounds for the Bayesian credible intervals used to summarize the results. The default is the equal tail 95 percent credible interval.

x

An object of class summary.eco.

digits

the number of significant digits to use when printing.

param

Logical. If TRUE, the posterior estimates of the population parameters will be provided. The default value is TRUE.

units

Logical. If TRUE, the in-sample predictions for each unit or for a subset of units will be provided. The default value is FALSE.

subset

A numeric vector indicating the subset of the units whose in-sample predications to be provided when units is TRUE. The default value is NULL where the in-sample predictions for each unit will be provided.

...

further arguments passed to or from other methods.

Value

summary.eco yields an object of class summary.eco containing the following elements:

call

The call from eco.

n.obs

The number of units.

n.draws

The number of Monte Carlo samples.

agg.table

Aggregate posterior estimates of the marginal means of \(W_1\) and \(W_2\) using \(X\) and \(N\) as weights.

If param = TRUE, the following elements are also included:
param.table

Posterior estimates of model parameters: population mean estimates of \(W_1\) and \(W_2\) and their logit transformations.

If units = TRUE, the following elements are also included:
W1.table

Unit-level posterior estimates for \(W_1\).

W2.table

Unit-level posterior estimates for \(W_2\).

This object can be printed by print.summary.eco

See Also

eco, predict.eco