summary method for class eco.
# S3 method for eco
summary(object, CI = c(2.5, 97.5), param = TRUE,
units = FALSE, subset = NULL, ...) # S3 method for summary.eco
print(x, digits = max(3, getOption("digits") - 3), ...)
An output object from eco.
A vector of lower and upper bounds for the Bayesian credible intervals used to summarize the results. The default is the equal tail 95 percent credible interval.
An object of class summary.eco.
the number of significant digits to use when printing.
Logical. If TRUE, the posterior estimates of the
population parameters will be provided. The default value is
TRUE.
Logical. If TRUE, the in-sample predictions for
each unit or for a subset of units will be provided. The default
value is FALSE.
A numeric vector indicating the subset of the units whose
in-sample predications to be provided when units is
TRUE. The default value is NULL where the in-sample
predictions for each unit will be provided.
further arguments passed to or from other methods.
summary.eco yields an object of class summary.eco
containing the following elements:
The call from eco.
The number of units.
The number of Monte Carlo samples.
Aggregate posterior estimates of the marginal means of \(W_1\) and \(W_2\) using \(X\) and \(N\) as weights.
Posterior estimates of model parameters: population mean estimates of \(W_1\) and \(W_2\) and their logit transformations.
Unit-level posterior estimates for \(W_1\).
Unit-level posterior estimates for \(W_2\).
This object can be printed by print.summary.eco
eco, predict.eco